@@ -8,9 +8,12 @@ pub mod evaluator;
 pub mod evaluator_context;
 pub mod evaluator_result;
 pub mod evaluator_value;
+pub mod user_agent_parsing;
 
 pub(crate) mod cmab_evaluator;
 pub(crate) mod comparisons;
 pub(crate) mod country_lookup;
 pub(crate) mod get_unit_id;
-pub(crate) mod ua_parser;
+
+#[cfg(test)]
+mod __tests__;
