@@ -65,6 +65,8 @@ pub struct StatsigOptions {
     pub wait_for_user_agent_init: Option<bool>,
 
     pub proxy_config: Option<ProxyConfig>,
+
+    pub __experimental_ua_parsing_enabled: Option<bool>,
 }
 
 impl StatsigOptions {
@@ -207,6 +209,9 @@ impl StatsigOptionsBuilder {
     }
 
     #[must_use]
+    #[deprecated(
+        note = "This field is deprecated and will be removed in a future release. It is no longer consumed and can be removed safely."
+    )]
     pub fn config_compression_mode(
         mut self,
         config_compression_mode: Option<ConfigCompressionMode>,
